unit GeoIPHelper;

{$RTTI EXPLICIT METHODS([]) PROPERTIES([]) FIELDS([])}

interface

function GetCountryCodeGeoIP(const IP: String): String;
function GetCountryIndexGeoIP(const IP: String): Integer;
function GetCountryNameGeoIP(const IP: String): String;
function GetCityNameGeoIP(const IP: String): String;
function GetStateNameGeoIP(const IP: String): String;
function GetCityZIPGeoIP(const IP: String): string;

implementation

uses
  Windows, SysUtils, GeoIP, SyncObjs, mySecSharedFuncUnit;

var
  xGeoIPCountry: TGeoIP;
  xGeoIPCity: TGeoIP;
  GeoCS: TCriticalSection;

const
  CGeoIPCountryFile = 'bin\GeoIP.dat';
  CGeoIPCityFile = 'bin\GeoIPCity.dat';

function GetCountryCodeGeoIP(const IP: String): String;
var
  GeoIPCountry: TGeoIPCountry;
begin
  GeoCS.Enter;

  if xGeoIPCountry.GetCountry(AnsiString(IP), GeoIPCountry) = GEOIP_SUCCESS then
    Result := String(GeoIPCountry.CountryCode)
  else
    Result := '';

  GeoCS.Leave;
end;

function GetCountryNameGeoIP(const IP: String): String;
var
  GeoIPCountry: TGeoIPCountry;
begin
  GeoCS.Enter;

  if xGeoIPCountry.GetCountry(AnsiString(IP), GeoIPCountry) = GEOIP_SUCCESS then
    Result := String(GeoIPCountry.CountryName)
  else
    Result := '';

  GeoCS.Leave;
end;

function GetCityZIPGeoIP(const IP: String): String;
var
  GeoIPCity: TGeoIPCity;
begin
  GeoCS.Enter;

  if (xGeoIPCity <> nil) and (xGeoIPCity.GetCity(AnsiString(IP), GeoIPCity)
    = GEOIP_SUCCESS) then
    Result := String(GeoIPCity.PostalCode)
  else
    Result := '';

  GeoCS.Leave;
end;

function GetCityNameGeoIP(const IP: String): String;
var
  GeoIPCity: TGeoIPCity;
begin
  GeoCS.Enter;

  if (xGeoIPCity <> nil) and (xGeoIPCity.GetCity(AnsiString(IP), GeoIPCity)
    = GEOIP_SUCCESS) then
    Result := String(GeoIPCity.City)
  else
    Result := '';

  GeoCS.Leave;
end;

function GetStateNameGeoIP(const IP: String): String;
var
  GeoIPCity: TGeoIPCity;
begin
  GeoCS.Enter;

  if (xGeoIPCity <> nil) and (xGeoIPCity.GetCity(AnsiString(IP), GeoIPCity)
    = GEOIP_SUCCESS) then
    Result := String(GeoIPCity.Region)
  else
    Result := '';

  GeoCS.Leave;
end;

function GetCountryIndexGeoIP(const IP: String): Integer;
var
  GeoIPCountry: TGeoIPCountry;
begin
  GeoCS.Enter;

  if xGeoIPCountry.GetCountry(AnsiString(IP), GeoIPCountry) = GEOIP_SUCCESS then
    Result := GeoIPCountry.Index
  else
    Result := -1;

  GeoCS.Leave;
end;

function GetResourcePointer(const Res: String; var Size: LongWord;
  var hgRes: hGlobal): Pointer;
var
  SRC: HRSRC;
begin
  Result := nil;
  SRC := FindResource(0, PChar(Res), RT_RCDATA);
  if SRC = 0 then
    Exit;
  Size := SizeOfResource(0, SRC);
  if Size = 0 then
    Exit;
  hgRes := LoadResource(0, SRC);
  if hgRes = 0 then
    Exit;
  Result := LockResource(hgRes);
end;

initialization

GeoCS := TCriticalSection.Create;

if FileExists(AppDir + CGeoIPCountryFile) then
  xGeoIPCountry := TGeoIP.Create(AppDir + CGeoIPCountryFile);

if FileExists(AppDir + CGeoIPCityFile) then
  xGeoIPCity := TGeoIP.Create(AppDir + CGeoIPCityFile);

finalization

FreeAndNil(GeoCS);
FreeAndNil(xGeoIPCountry);
FreeAndNil(xGeoIPCity);

end.
